import React, { useCallback, useContext, useEffect, useState } from 'react';
import { CloseBtn } from '../../../CloseBtn';
import { Modal } from '../../../Modal';
import { ScreenMedia } from '../../../ScreenMedia';
import { IPageListingChildrenProps } from '../PageListing.interface';
import { PageListingContext } from '../PageListingContext';
import { IFiltersComponentProps } from './FiltersContainer.interface';
import * as S from './FiltersContainer.style';

export function FiltersContainer(): JSX.Element {
   const context = useContext(PageListingContext);

   return <FiltersComponent {...context} />;
}

const FiltersComponent = function FiltersComponent(props: IPageListingChildrenProps): JSX.Element {
   return (
      <S.FiltersContainerStyle>
         <FiltersDesktop
            FiltersComponent={props.FiltersComponent}
            handleFilters={props.handleFilters}
            clearFilters={props.clearFilters}
            filters={props.filters}
         />
         <FiltersMobile
            FiltersComponent={props.FiltersComponent}
            handleFilters={props.handleFiltersMobile}
            clearFilters={props.clearFiltersMobile}
            closeFilters={props.closeFilters}
            applyFilters={props.applyFilters}
            filters={props.filters}
            filterMobileOpen={props.filterMobileOpen}
         />
      </S.FiltersContainerStyle>
   );
};

const FiltersDesktop = function FiltersDesktop(props: any): JSX.Element {
   const { FiltersComponent } = props;

   return (
      <ScreenMedia showIn="desktop">
         <div className="filters">
            <div className="filters-title">
               Filtrar
               <div className="clear-filters" onClick={props.clearFilters} data-cy="clear-desktop-filters">
                  LIMPAR
               </div>
            </div>

            <div className="filters-content" data-cy="desktop-filters">
               <FiltersComponent handleFilters={props.handleFilters} filters={props.filters} />
            </div>
         </div>
      </ScreenMedia>
   );
};

function FiltersMobile({
   clearFilters,
   filterMobileOpen,
   FiltersComponent,
   closeFilters,
   applyFilters,
   handleFilters,
   filters,
}): JSX.Element {
   return (
      <ScreenMedia size="mobile">
         <Modal show={filterMobileOpen} animation="slideDown">
            <S.FiltersMobileStyle>
               <div className="filters-title">
                  Filtrar
                  <div className="clear-filters text-primary" onClick={clearFilters} data-cy="clear-mobile-filters">
                     LIMPAR FILTROS
                  </div>
                  <div className="close-btn" onClick={closeFilters}>
                     <CloseBtn />
                  </div>
               </div>

               <div className="filters-body">
                  <FiltersComponent handleFilters={handleFilters} filters={filters} />
               </div>

               <div className="filters-btn" data-cy="btn-mobile-filters">
                  <button className="btn btn-primary" onClick={applyFilters} type="button">
                     Filtrar
                  </button>
               </div>
            </S.FiltersMobileStyle>
         </Modal>
      </ScreenMedia>
   );
}
